List all functions defined within an R source file. Default to using the currently active file.
Usage
list_functions(path = current_file())Examples
if(interactive()) list_functions()
List all functions defined within an R source file. Default to using the currently active file.
list_functions(path = current_file())if(interactive()) list_functions()